PyXMake Developer Guide: PyXMake.VTL.stm_cara Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions | Variables
PyXMake.VTL.stm_cara Namespace Reference

## Functions
| main (user, key="", password="", verbosity=0, **kwargs)

## Variables
| parser = argparse.ArgumentParser(description="Install supported STM software in the user's workspace on CARA.")
| metavar
| nargs
| help
| type
| GetBoolean
| const
| True
| default
| False
| _ = sys.argv[1]
| args
str | user = "";
| password = args.password[0]
| access
| directory
| feature
| refresh
| interactive
| key = os.path.join(Utility.AsDrive("C"),"Users",user,"Keys","Putty","id_rsa")
| auth

## Detailed Description

    Install latest STM software on DLR's HPC cluster (CARA).

    @note: Requires GitLab access
    Created on 21.07.2020

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          -

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

PyXMake.VTL.stm_cara.main | ( |  | user,
|  |  | key = "",
|  |  | password = "",
|  |  | verbosity = 0,
|  | ** | kwargs )

    Main function to execute the script.
    Install STM software in the user's workspace on CARA. Installs all packages.

Definition at line 47 of file stm_cara.py.

## Variable Documentation

## ◆ _

PyXMake.VTL.stm_cara._ = sys.argv[1]
| protected

Definition at line 90 of file stm_cara.py.

## ◆ access

PyXMake.VTL.stm_cara.access

Definition at line 100 of file stm_cara.py.

## ◆ args

PyXMake.VTL.stm_cara.args

Definition at line 91 of file stm_cara.py.

## ◆ auth

PyXMake.VTL.stm_cara.auth

Definition at line 120 of file stm_cara.py.

## ◆ const

PyXMake.VTL.stm_cara.const

Definition at line 87 of file stm_cara.py.

## ◆ default

PyXMake.VTL.stm_cara.default

Definition at line 87 of file stm_cara.py.

## ◆ directory

PyXMake.VTL.stm_cara.directory

Definition at line 103 of file stm_cara.py.

## ◆ False

PyXMake.VTL.stm_cara.False

Definition at line 87 of file stm_cara.py.

## ◆ feature

PyXMake.VTL.stm_cara.feature

Definition at line 106 of file stm_cara.py.

## ◆ GetBoolean

PyXMake.VTL.stm_cara.GetBoolean

Definition at line 87 of file stm_cara.py.

## ◆ help

PyXMake.VTL.stm_cara.help

Definition at line 81 of file stm_cara.py.

## ◆ interactive

PyXMake.VTL.stm_cara.interactive

Definition at line 112 of file stm_cara.py.

## ◆ key

PyXMake.VTL.stm_cara.key = os.path.join(Utility.AsDrive("C"),"Users",user,"Keys","Putty","id_rsa")

Definition at line 117 of file stm_cara.py.

## ◆ metavar

PyXMake.VTL.stm_cara.metavar

Definition at line 81 of file stm_cara.py.

## ◆ nargs

PyXMake.VTL.stm_cara.nargs

Definition at line 81 of file stm_cara.py.

## ◆ parser

PyXMake.VTL.stm_cara.parser = argparse.ArgumentParser(description="Install supported STM software in the user's workspace on CARA.")

Definition at line 80 of file stm_cara.py.

## ◆ password

PyXMake.VTL.stm_cara.password = args.password[0]

Definition at line 98 of file stm_cara.py.

## ◆ refresh

PyXMake.VTL.stm_cara.refresh

Definition at line 109 of file stm_cara.py.

## ◆ True

PyXMake.VTL.stm_cara.True

Definition at line 87 of file stm_cara.py.

## ◆ type

PyXMake.VTL.stm_cara.type

Definition at line 87 of file stm_cara.py.

## ◆ user

str PyXMake.VTL.stm_cara.user = "";

Definition at line 97 of file stm_cara.py.